@@ -1,12 +1,12 @@
-from typing import Any, List, Sequence, Tuple
+from typing import Any, Sequence, Tuple
 
 import torch
 from transformers import AutoModelForSeq2SeqLM, BatchEncoding
 from transformers.modeling_outputs import Seq2SeqLMOutput
 
-from pytorch_ie.core.pytorch_ie import PyTorchIEModel
-from pytorch_ie.data import Metadata
-from pytorch_ie.document import TextDocument
+from pytorch_ie.core import PyTorchIEModel
+from pytorch_ie.core.taskmodule import Metadata
+from pytorch_ie.documents import TextDocument
 
 TransformerSeq2SeqModelBatchEncoding = BatchEncoding
 TransformerSeq2SeqModelBatchOutput = Seq2SeqLMOutput  # TODO: is this the correct type?
@@ -16,6 +16,7 @@ TransformerSeq2SeqModelStepBatchEncoding = Tuple[
 ]
 
 
+@PyTorchIEModel.register()
 class TransformerSeq2SeqModel(PyTorchIEModel):
     def __init__(
         self,
