@@ -7,12 +7,13 @@ from transformers import AutoTokenizer
 from transformers.file_utils import PaddingStrategy
 from transformers.tokenization_utils_base import BatchEncoding, TruncationStrategy
 
-from pytorch_ie import BinaryRelation, LabeledSpan, MultiLabeledBinaryRelation, Span, TextDocument
+from pytorch_ie.annotations import BinaryRelation, LabeledSpan, MultiLabeledBinaryRelation, Span
+from pytorch_ie.core import TaskEncoding, TaskModule
+from pytorch_ie.documents import TextDocument
 from pytorch_ie.models import (
     TransformerTextClassificationModelBatchOutput,
     TransformerTextClassificationModelStepBatchEncoding,
 )
-from pytorch_ie.taskmodules.taskmodule import TaskEncoding, TaskModule
 from pytorch_ie.utils.span import get_token_slice, is_contained_in
 from pytorch_ie.utils.window import get_window_around_slice
 
@@ -111,6 +112,7 @@ def _enumerate_entity_pairs(
             yield head, tail
 
 
+@TaskModule.register()
 class TransformerRETextClassificationTaskModule(_TransformerReTextClassificationTaskModule):
     """
     Marker based relation extraction. This taskmodule prepares the input token ids in such a way
